@@ -138,20 +138,20 @@ inline StepCore::Gas* GasVertexHandlerGraphicsItem::gas() const
 }
 
 StepCore::Vector2d GasVertexHandlerGraphicsItem::value() {
-    return gas()->measureRectSize().cwise()*(corners[_vertexNum]);
+    return (gas()->measureRectSize().array()*(corners[_vertexNum]).array()).matrix();
 }
 
 void GasVertexHandlerGraphicsItem::setValue(const StepCore::Vector2d& value)
 {
     StepCore::Vector2d oCorner = gas()->measureRectCenter() -
-                    gas()->measureRectSize().cwise()*(corners[_vertexNum]);
+                    (gas()->measureRectSize().array()*(corners[_vertexNum].array())).matrix();
 
     StepCore::Vector2d delta = (gas()->measureRectCenter() + value - oCorner)/2.0;
     StepCore::Vector2d newPos = oCorner + delta;
     StepCore::Vector2d newSize = (newPos - oCorner)*2.0;
 
     double d = -0.1/currentViewScale();
-    StepCore::Vector2d sign = delta.cwise()*(corners[_vertexNum]);
+    StepCore::Vector2d sign = (delta.array()*(corners[_vertexNum].array())).matrix();
     if(sign[0] < d || sign[1] < d) {
         if(sign[0] < d) {
             newPos[0] = oCorner[0]; newSize[0] = 0;
@@ -270,7 +270,7 @@ OnHoverHandlerGraphicsItem* GasGraphicsItem::createOnHoverHandler(const QPointF&
 
     int num = -1; double minDist2 = HANDLER_SNAP_SIZE*HANDLER_SNAP_SIZE/s/s;
     for(unsigned int i=0; i<4; ++i) {
-        double dist2 = (l - size.cwise()*(OnHoverHandlerGraphicsItem::corners[i])).squaredNorm();
+        double dist2 = (l - (size.array()*(OnHoverHandlerGraphicsItem::corners[i]).array()).matrix()).squaredNorm();
         if(dist2 < minDist2) { num = i; minDist2 = dist2; }
     }
 
